/****************************************************************************
*   main.c -- PTC-II firmware update for Linux                              *
*   Copyright (C) 1998-1999  Peter Mack, DL3FCJ                             *
*                                                                           *
*   This program is free software; you can redistribute it and/or modify    *
*   it under the terms of the GNU General Public License as published by    *
*   the Free Software Foundation; either version 2 of the License, or       *
*   (at your option) any later version.                                     *
*                                                                           *
*   This program is distributed in the hope that it will be useful,         *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of          *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
*   GNU General Public License for more details.                            *
*                                                                           *
*   You should have received a copy of the GNU General Public License       *
*   along with this program; if not, write to the                           *
*   Free Software Foundation, Inc.                                          *
*   59 Temple Place, Suite 330, Boston, MA  02111-1307, USA.                *
*                                                                           *
****************************************************************************/

#include "main.h"


/*
 * global variables
 */
char	*version = "0.2";
struct termios	oldterm;


/*
 * usage
 */
void usage(void)
{
	fprintf(stderr, "\nUsage: update <device> <speed> <file>\n");
	fprintf(stderr,   "  e.g. update /dev/ttyS1 9600 ver5_8.pt2\n\n");
	exit(1);
}


/*
 * main...
 */
int main(int argc, char *argv[])
{
	int	speed;
	int	ser;
	int	res;
	struct termios	newterm;
	
	printf("The PTC-II firmware update for Linux.\nVersion %s.\n"
	       "(c) copyright 1998, 1999  Peter Mack, DL3FCJ.\n", version);

	if (argc < 4)
		usage();
	
	printf("\n");

	speed = atoi(argv[2]);
	ser = rs232_open (argv[1], speed);
	if(ser == -1) {
		exit(1);
	}
	
	/* if the PTC-II is in autobaud mode send a cr */
	write(ser, "\r", 1);
	
	rs232_readflush(ser); /* read and ignore the signon message */

	tcgetattr(STDIN_FILENO, &oldterm);
	
	newterm = oldterm;
	newterm.c_lflag &= ~ICANON;
	newterm.c_lflag &= ~ECHO;
	newterm.c_cc[VMIN] = 1;
	newterm.c_cc[VTIME] = 0;
	newterm.c_lflag &= ~ISIG;
	
	if(tcsetattr(STDIN_FILENO, TCSANOW, &newterm) != 0) {
		fprintf(stderr,"ERROR: Could not set console attributes.\n");
	}
	
	res = Update(ser, argv[3]);
	
	if (-1 == res) {
		fprintf(stderr, "Update failed!\n");
	} else if (-2 == res) {
		fprintf(stderr, "Update canceled by user!\n");
	}
	
	printf("\n");
	
	rs232_close(ser);

	tcsetattr(STDIN_FILENO, TCSANOW, &oldterm);

	exit(0);
}
